@@ -64,6 +64,8 @@ enum auctionErrorCode {
 	ae_captcha,
 	ae_cancelled,
 	ae_bidassistant,
+	ae_buyerblockprefitemcountlimitexceeded,
+	ae_bidgreaterthanbin_binblock,
 	/* ae_unknown must be last error */
 	ae_unknown
 };
